'filesysobjects.PySourceInfo' - Module
**************************************

.. automodule:: filesysobjects.PySourceInfo

Functions
---------

getSourceFilePathName
^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getSourceFilePathName

getSourceFuncName
^^^^^^^^^^^^^^^^^
	.. autofunction:: getSourceFuncName

getSourceLinenumber
^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getSourceLinenumber

getCallerName
^^^^^^^^^^^^^
	.. autofunction:: getCallerName

getCallerNameOID
^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerNameOID

getCallerPackageName
^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPackageName

getCallerPackagePathName
^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPackagePathName

getCallerPackagePythonPath
^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPackagePythonPath

getCallerPackageFilePathName
^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerPackageFilePathName

getCallerModuleFilePathName
^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModuleFilePathName

getCallerModuleName
^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModuleName

getCallerModulePythonPath
^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModulePythonPath

getCallerModulePathName
^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getCallerModulePathName

getPythonPathPrefixMatchFromSysPath
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getPythonPathPrefixMatchFromSysPath

getPythonPathModuleRel
^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getPythonPathModuleRel

getPythonPathForPackage
^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getPythonPathForPackage

